.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Light Curve Fitting Documentation
=================================

This package contains tools to fit analytical models to multiband light curves of astronomical transients.
If you use this code in a publication, please **cite the original papers** whose models you used (see :ref:`References`), as well as my Zenodo repository.

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.2639463.svg
   :target: https://doi.org/10.5281/zenodo.2639463


.. toctree::
   :maxdepth: 2

   installation
   usage
   api
   release-history

References
----------
.. [C08] Conley et al. 2008, ApJ, 681, 482, doi:`10.1086/588518 <https://doi.org/10.1086/588518>`_
.. [H17] Hosseinzadeh et al. 2017, ApJL, 845, L11, doi:`10.3847/2041-8213/aa8402 <https://doi.org/10.3847/2041-8213/aa8402>`_
.. [H18] Hosseinzadeh et al. 2018, ApJ, 861, 63, doi:`10.3847/1538-4357/aac5f6 <https://doi.org/10.3847/1538-4357/aac5f6>`_
.. [H22a] Hosseinzadeh et al. 2022a, ApJL, 933, L45, doi:`10.3847/2041-8213/ac7cef <https://doi.org/10.3847/2041-8213/ac7cef>`_
.. [H22b] Hosseinzadeh et al. 2022b, ApJ, 935, 31, doi:`10.3847/1538-4357/ac75f0 <https://doi.org/10.3847/1538-4357/ac75f0>`_
.. [K10] Kasen 2010, ApJ, 708, 1025, doi:`10.1088/0004-637X/708/2/1025 <https://doi.org/10.1088/0004-637X/708/2/1025>`_
.. [RW11] Rabinak & Waxman 2011, ApJ, 728, 63, doi:`10.1088/0004-637X/728/1/63 <https://doi.org/10.1088/0004-637X/728/1/63>`_
.. [SW17] Sapir & Waxman 2017, ApJ, 838, 130, doi:`10.3847/1538-4357/aa64df <https://doi.org/10.3847/1538-4357/aa64df>`_
